@@ -26,24 +26,25 @@ NULL
 #' @importFrom purrr map_lgl
 #' @importFrom rlang seq2
 #' @keywords internal
-update_indention_ref_fun_call <- function(pd_nested) {
-  current_is_call <- pd_nested$token_before[2] %in% c("SYMBOL_FUNCTION_CALL")
-  non_comment <- which(pd_nested$token != "COMMENT")
-  first_non_comment_after_call <- non_comment[non_comment > 2][1]
-  if ((current_is_call) &&
-    pd_nested$lag_newlines[first_non_comment_after_call] == 0) {
-    candidates <- seq2(3, nrow(pd_nested) - 1)
-
-    child_is_call <- map_lgl(pd_nested$child, is_function_call)
-    child_is_curly_expr <- map_lgl(pd_nested$child, is_curly_expr)
-    child_is_on_same_line <- cumsum(pd_nested$lag_newlines) == 0
-    call_on_same_line <- child_is_call & child_is_on_same_line
-    to_indent <- setdiff(candidates, which(call_on_same_line | child_is_curly_expr))
-
-    pd_nested$indention_ref_pos_id[to_indent] <- last(pd_nested$child[[1]]$pos_id)
-  }
-  pd_nested
-}
+# update_indention_ref_fun_call <- function(pd_nested) {
+#   current_is_call <- pd_nested$token_before[2] %in% c("SYMBOL_FUNCTION_CALL")
+#   non_comment <- which(pd_nested$token != "COMMENT")
+#   first_non_comment_after_call <- non_comment[non_comment > 2][1]
+#   if ((current_is_call) &&
+#     pd_nested$lag_newlines[first_non_comment_after_call] == 0) {
+#     candidates <- seq2(3, nrow(pd_nested) - 1)
+#
+#     child_is_call <- map_lgl(pd_nested$child, is_function_call)
+#     child_is_curly_expr <- map_lgl(pd_nested$child, is_curly_expr)
+#     child_is_on_same_line <- cumsum(pd_nested$lag_newlines) == 0
+#     call_on_same_line <- child_is_call & child_is_on_same_line
+#     to_indent <- setdiff(candidates, which(call_on_same_line | child_is_curly_expr))
+#
+#     pd_nested$indention_ref_pos_id[to_indent] <- last(pd_nested$child[[1]]$pos_id)
+#   }
+#   pd_nested
+# }
+NULL
 
 #' @describeIn update_indention_ref Updates the reference pos_id for all
 #'   tokens in `pd_nested` if `pd_nested` contains a function declaration.
@@ -54,7 +55,7 @@ update_indention_ref_fun_call <- function(pd_nested) {
 #' \dontrun{
 #' a <- function(x,
 #'               y) {
-#' x + y
+#'   x + y
 #' }
 #' }
 #' @importFrom rlang seq2
@@ -96,7 +97,6 @@ apply_ref_indention <- function(flattened_pd) {
 #'   should be applied to other tokens.
 #' @keywords internal
 apply_ref_indention_one <- function(flattened_pd, target_token) {
-
   token_to_update <- find_tokens_to_update(flattened_pd, target_token)
   # udate spaces
   copied_spaces <- flattened_pd$col2[target_token]
@@ -123,12 +123,12 @@ apply_ref_indention_one <- function(flattened_pd, target_token) {
 #' @seealso apply_ref_indention_one()
 #' @examples
 #' style_text("function(a =
-#'   b,
-#'   dd
+#' b,
+#' dd
 #' ) {}", scope = "indention")
 #' style_text("function(a,
-#'   b,
-#'   dd
+#' b,
+#' dd
 #' ) {}", scope = "indention")
 #' @keywords internal
 find_tokens_to_update <- function(flattened_pd, target_token) {
