@@ -5,11 +5,11 @@ tidyverse_with_pipe_expection_style <- function(..., strict = TRUE) {
     if (styler:::is_curly_expr(pd) && nrow(pd) > 2) {
       closing_before <- pd$token == "'}'"
       opening_before <- (pd$token == "'{'") & (pd$token_after != "COMMENT")
-      to_break <- lag(opening_before, default =FALSE) | closing_before
+      to_break <- lag(opening_before, default = FALSE) | closing_before
       len_to_break <- sum(to_break)
       pd$lag_newlines[to_break] <- ifelse(rep(TRUE, len_to_break),
-                                          1L,
-                                          pmax(1L, pd$lag_newlines[to_break])
+        1L,
+        pmax(1L, pd$lag_newlines[to_break])
       )
     }
     pd
@@ -24,4 +24,5 @@ style_text("
            x <- 3
            function() {ifelse(. > 5, NA, .)}
            ",
-  scope = "line_breaks", style = tidyverse_with_pipe_expection_style)
+  scope = "line_breaks", style = tidyverse_with_pipe_expection_style
+)
