@@ -4,20 +4,40 @@ line_col_names <- function() {
   c("line1", "line2", "col1", "col2")
 }
 
+ensure_last_is_empty <- function(x) {
+  has_line_break_at_eof <- x[length(x)] == ""
+  if (has_line_break_at_eof) {
+    return(x)
+  } else {
+    append(x, "")
+  }
+}
+
 #' Check whether two columns match
 #'
 #' @param col1,col2 Column names as string.
 #' @param data The data frames that contains `col1` and `col2`.
+#' @keywords internal
 two_cols_match <- function(col1, col2, data) {
   all(unlist(data[col1]) == unlist(data[col2]))
 }
 
 odd <- function(x) {
-  x[seq(1L, length(x), by = 2)]
+  x[odd_index(x)]
+}
+
+odd_index <- function(x) {
+  if (length(x) < 1) return(NULL)
+  seq(1L, length(x), by = 2)
 }
 
 even <- function(x) {
-  x[seq(2L, length(x), by = 2)]
+  if (length(x) < 2) return(NULL)
+  x[even_index(x)]
+}
+
+even_index <- function(x) {
+  seq(2L, length(x), by = 2)
 }
 
 #' Repeat elements of a character vector `times` times and collapse it
@@ -73,6 +93,10 @@ is_rmd_file <- function(path) {
   grepl("\\.Rmd$", path, ignore.case = TRUE)
 }
 
+is_rnw_file <- function(path) {
+  grepl("\\.Rnw$", path, ignore.case = TRUE)
+}
+
 is_unsaved_file <- function(path) {
   path == ""
 }
