@@ -118,8 +118,7 @@ test <- function() {
 
   nested(
     function_call (with),
-    many
-    ,     first_level_args)
+    many,     first_level_args)
 
   nested(
     function_call (with),  # a comment and
