@@ -1,7 +1,13 @@
 context("various helpers")
 
-test_that("can construct vertical", {
+test_that("can construct and print vertical", {
   expect_error(construct_vertical(c("1 + 1", "nw")), NA)
+  expect_error(construct_vertical(c("1 + 1", "nw")) %>% print(), NA)
+})
+
+
+test_that("file types can be asserted", {
+  expect_error(assert_filetype(".Rnw"), "case is ignored")
 })
 
 test_that("can lookup tokens", {
